define(
//begin v1.x content
{
	"dayPeriods-standAlone-abbr-noon": "정오",
	"field-tue-relative+-1": "지난 화요일",
	"field-year": "년",
	"dateFormatItem-MEEEEd": "M. d. EEEE",
	"dateFormatItem-yw": "Y년 w번째 주",
	"dayPeriods-format-abbr-afternoon1": "오후",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "이번 수요일",
	"field-wed-relative+1": "다음 수요일",
	"dateFormatItem-ms": "mm:ss",
	"timeFormat-short": "a h:mm",
	"field-minute": "분",
	"field-tue-narrow-relative+0": "이번 화요일",
	"field-tue-narrow-relative+1": "다음 화요일",
	"field-thu-short-relative+0": "이번 목요일",
	"dateTimeFormat-short": "{1} {0}",
	"field-thu-short-relative+1": "다음 목요일",
	"field-day-relative+0": "오늘",
	"field-day-relative+1": "내일",
	"field-day-relative+2": "모레",
	"field-wed-narrow-relative+-1": "지난 수요일",
	"dateFormatItem-EBhms": "(E) B h:mm:ss",
	"field-year-narrow": "년",
	"field-era-short": "연호",
	"field-tue-relative+0": "이번 화요일",
	"field-tue-relative+1": "다음 화요일",
	"field-weekdayOfMonth": "월의 평일",
	"field-second-short": "초",
	"dayPeriods-format-narrow-am": "AM",
	"dayPeriods-standAlone-abbr-morning1": "새벽",
	"dayPeriods-standAlone-abbr-morning2": "오전",
	"dateFormatItem-MMMd": "MMM d일",
	"dayPeriods-format-narrow-morning1": "새벽",
	"field-weekdayOfMonth-narrow": "월의 평일",
	"dayPeriods-format-narrow-morning2": "오전",
	"dayPeriods-format-abbr-am": "AM",
	"field-week-relative+0": "이번 주",
	"field-month-relative+0": "이번 달",
	"field-week-relative+1": "다음 주",
	"field-month-relative+1": "다음 달",
	"field-sun-narrow-relative+0": "이번 일요일",
	"timeFormat-medium": "a h:mm:ss",
	"field-mon-short-relative+0": "이번 월요일",
	"field-sun-narrow-relative+1": "다음 일요일",
	"field-mon-short-relative+1": "다음 월요일",
	"field-second-relative+0": "지금",
	"months-standAlone-narrow": [
		"1월",
		"2월",
		"3월",
		"4월",
		"5월",
		"6월",
		"7월",
		"8월",
		"9월",
		"10월",
		"11월",
		"12월"
	],
	"dayPeriods-standAlone-wide-noon": "정오",
	"eraNames": [
		"기원전",
		"서기"
	],
	"field-weekOfMonth": "월의 주",
	"dayPeriods-standAlone-abbr-pm": "PM",
	"field-month-short": "월",
	"dateFormatItem-GyMMMEd": "G y년 MMM d일 (E)",
	"field-day": "일",
	"dayPeriods-standAlone-wide-night1": "밤",
	"field-dayOfYear-short": "년의 일",
	"field-year-relative+-1": "작년",
	"dayPeriods-format-wide-am": "오전",
	"field-sat-short-relative+-1": "지난 토요일",
	"dayPeriods-format-narrow-afternoon1": "오후",
	"dayPeriods-format-wide-afternoon1": "오후",
	"field-hour-relative+0": "현재 시간",
	"field-wed-relative+-1": "지난 수요일",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "지난 토요일",
	"field-second": "초",
	"days-standAlone-narrow": [
		"일",
		"월",
		"화",
		"수",
		"목",
		"금",
		"토"
	],
	"dayPeriods-standAlone-narrow-noon": "정오",
	"dayPeriods-standAlone-wide-pm": "오후",
	"dateFormatItem-Ehms": "(E) a h:mm:ss",
	"dateFormat-long": "y년 M월 d일",
	"dateFormatItem-GyMMMd": "G y년 MMM d일",
	"dayPeriods-standAlone-abbr-midnight": "자정",
	"field-quarter": "분기",
	"field-week-short": "주",
	"dayPeriods-format-narrow-midnight": "자정",
	"dateFormatItem-yMMMEd": "y년 MMM d일 (E)",
	"dateFormatItem-MMMEEEEd": "MMM d일 EEEE",
	"quarters-standAlone-wide": [
		"제 1/4분기",
		"제 2/4분기",
		"제 3/4분기",
		"제 4/4분기"
	],
	"days-format-narrow": [
		"일",
		"월",
		"화",
		"수",
		"목",
		"금",
		"토"
	],
	"dayPeriods-format-wide-evening1": "저녁",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-tue-short-relative+0": "이번 화요일",
	"field-tue-short-relative+1": "다음 화요일",
	"field-mon-relative+-1": "지난 월요일",
	"dateFormatItem-GyMMM": "G y년 MMM",
	"field-month": "월",
	"field-day-narrow": "일",
	"dayPeriods-standAlone-abbr-night1": "밤",
	"dayPeriods-standAlone-narrow-afternoon1": "오후",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "분",
	"field-dayperiod": "오전/오후",
	"field-sat-short-relative+0": "이번 토요일",
	"field-sat-short-relative+1": "다음 토요일",
	"dayPeriods-format-narrow-pm": "PM",
	"dateFormat-medium": "y. M. d.",
	"dateFormatItem-EEEEd": "d일 EEEE",
	"eraAbbr": [
		"BC",
		"AD"
	],
	"quarters-standAlone-abbr": [
		"1분기",
		"2분기",
		"3분기",
		"4분기"
	],
	"dayPeriods-format-abbr-pm": "PM",
	"field-second-narrow": "초",
	"field-mon-relative+0": "이번 월요일",
	"dayPeriods-standAlone-narrow-night1": "밤",
	"field-mon-relative+1": "다음 월요일",
	"field-year-short": "년",
	"months-format-narrow": [
		"1월",
		"2월",
		"3월",
		"4월",
		"5월",
		"6월",
		"7월",
		"8월",
		"9월",
		"10월",
		"11월",
		"12월"
	],
	"dayPeriods-format-wide-morning1": "새벽",
	"dayPeriods-format-wide-morning2": "오전",
	"field-quarter-relative+-1": "지난 분기",
	"field-dayperiod-narrow": "오전/오후",
	"dayPeriods-standAlone-narrow-am": "AM",
	"days-format-short": [
		"일",
		"월",
		"화",
		"수",
		"목",
		"금",
		"토"
	],
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"dayPeriods-format-wide-pm": "오후",
	"field-dayOfYear": "년의 일",
	"field-sat-relative+-1": "지난 토요일",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "M. d.",
	"field-hour": "시",
	"dateFormatItem-yQQQQ": "y년 QQQQ",
	"months-format-wide": [
		"1월",
		"2월",
		"3월",
		"4월",
		"5월",
		"6월",
		"7월",
		"8월",
		"9월",
		"10월",
		"11월",
		"12월"
	],
	"dayPeriods-format-wide-night1": "밤",
	"dateFormat-full": "y년 M월 d일 EEEE",
	"field-month-relative+-1": "지난달",
	"dateFormatItem-Hms": "H시 m분 s초",
	"field-quarter-short": "분기",
	"field-sat-narrow-relative+0": "이번 토요일",
	"dateFormatItem-Hmv": "HH:mm v",
	"field-fri-relative+0": "이번 금요일",
	"field-sat-narrow-relative+1": "다음 토요일",
	"field-fri-relative+1": "다음 금요일",
	"dateFormatItem-EBhm": "(E) B h:mm",
	"dayPeriods-format-narrow-noon": "정오",
	"field-sun-short-relative+0": "이번 일요일",
	"field-sun-short-relative+1": "다음 일요일",
	"field-week-relative+-1": "지난주",
	"dateFormatItem-Ehm": "(E) a h:mm",
	"months-format-abbr": [
		"1월",
		"2월",
		"3월",
		"4월",
		"5월",
		"6월",
		"7월",
		"8월",
		"9월",
		"10월",
		"11월",
		"12월"
	],
	"dayPeriods-format-wide-midnight": "자정",
	"field-quarter-relative+0": "이번 분기",
	"field-minute-relative+0": "현재 분",
	"timeFormat-long": "a h시 m분 s초 z",
	"field-quarter-relative+1": "다음 분기",
	"field-wed-short-relative+-1": "지난 수요일",
	"dateFormatItem-yMMM": "y년 MMM",
	"dateFormat-short": "yy. M. d.",
	"dateFormatItem-Bh": "B h시",
	"dayPeriods-format-abbr-night1": "밤",
	"dateFormatItem-MMMMW": "MMMM W번째 주",
	"field-thu-short-relative+-1": "지난 목요일",
	"days-standAlone-wide": [
		"일요일",
		"월요일",
		"화요일",
		"수요일",
		"목요일",
		"금요일",
		"토요일"
	],
	"field-mon-narrow-relative+-1": "지난 월요일",
	"dateFormatItem-yMMMEEEEd": "y년 MMM d일 EEEE",
	"dateFormatItem-MMMMd": "MMMM d일",
	"field-thu-narrow-relative+-1": "지난 목요일",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-mmss": "mm:ss",
	"dateFormatItem-H": "H시",
	"field-weekOfMonth-short": "월의 주",
	"field-tue-narrow-relative+-1": "지난 화요일",
	"dayPeriods-format-abbr-evening1": "저녁",
	"dayPeriods-standAlone-narrow-pm": "PM",
	"dateFormatItem-M": "M월",
	"months-standAlone-wide": [
		"1월",
		"2월",
		"3월",
		"4월",
		"5월",
		"6월",
		"7월",
		"8월",
		"9월",
		"10월",
		"11월",
		"12월"
	],
	"field-wed-short-relative+0": "이번 수요일",
	"field-wed-short-relative+1": "다음 수요일",
	"dateFormatItem-Hmsv": "H시 m분 s초 v",
	"field-sun-relative+-1": "지난 일요일",
	"days-standAlone-abbr": [
		"일",
		"월",
		"화",
		"수",
		"목",
		"금",
		"토"
	],
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-HHmmss": "HH:mm:ss",
	"dateFormatItem-hm": "a h:mm",
	"dateFormatItem-d": "d일",
	"field-weekday": "요일",
	"dayPeriods-standAlone-wide-evening1": "저녁",
	"field-sat-relative+0": "이번 토요일",
	"dateFormatItem-h": "a h시",
	"field-sat-relative+1": "다음 토요일",
	"months-standAlone-abbr": [
		"1월",
		"2월",
		"3월",
		"4월",
		"5월",
		"6월",
		"7월",
		"8월",
		"9월",
		"10월",
		"11월",
		"12월"
	],
	"dateFormatItem-hmsv": "a h:mm:ss v",
	"dayPeriods-format-abbr-morning1": "새벽",
	"dayPeriods-standAlone-narrow-evening1": "저녁",
	"dateFormatItem-yMM": "y. M.",
	"dayPeriods-format-abbr-morning2": "오전",
	"field-dayOfYear-narrow": "년의 일",
	"timeFormat-full": "a h시 m분 s초 zzzz",
	"field-weekdayOfMonth-short": "월의 평일",
	"dateFormatItem-MEd": "M. d. (E)",
	"field-zone-narrow": "시간대",
	"dateFormatItem-y": "y년",
	"field-thu-narrow-relative+0": "이번 목요일",
	"field-sun-narrow-relative+-1": "지난 일요일",
	"field-mon-short-relative+-1": "지난 월요일",
	"field-thu-narrow-relative+1": "다음 목요일",
	"field-thu-relative+0": "이번 목요일",
	"dayPeriods-standAlone-abbr-afternoon1": "오후",
	"field-thu-relative+1": "다음 목요일",
	"dateFormatItem-hms": "a h:mm:ss",
	"field-fri-short-relative+-1": "지난 금요일",
	"dateFormatItem-hmv": "a h:mm v",
	"dayPeriods-format-abbr-noon": "정오",
	"field-thu-relative+-1": "지난 목요일",
	"dateFormatItem-yMd": "y. M. d.",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-week": "주",
	"quarters-format-wide": [
		"제 1/4분기",
		"제 2/4분기",
		"제 3/4분기",
		"제 4/4분기"
	],
	"dateFormatItem-Ed": "d일 (E)",
	"field-wed-narrow-relative+0": "이번 수요일",
	"field-wed-narrow-relative+1": "다음 수요일",
	"dayPeriods-standAlone-wide-morning1": "새벽",
	"dayPeriods-standAlone-wide-morning2": "오전",
	"field-dayperiod-short": "오전/오후",
	"field-fri-short-relative+0": "이번 금요일",
	"field-fri-short-relative+1": "다음 금요일",
	"days-standAlone-short": [
		"일",
		"월",
		"화",
		"수",
		"목",
		"금",
		"토"
	],
	"dayPeriods-standAlone-narrow-morning1": "새벽",
	"dayPeriods-standAlone-narrow-morning2": "오전",
	"dayPeriods-format-abbr-midnight": "자정",
	"field-hour-short": "시",
	"field-zone-short": "시간대",
	"quarters-format-abbr": [
		"1분기",
		"2분기",
		"3분기",
		"4분기"
	],
	"field-month-narrow": "월",
	"field-hour-narrow": "시",
	"field-fri-narrow-relative+-1": "지난 금요일",
	"field-year-relative+0": "올해",
	"field-era-narrow": "연호",
	"field-year-relative+1": "내년",
	"field-fri-relative+-1": "지난 금요일",
	"eraNarrow": [
		"BC",
		"AD"
	],
	"dateFormatItem-Bhms": "B h:mm:ss",
	"dayPeriods-format-wide-noon": "정오",
	"field-tue-short-relative+-1": "지난 화요일",
	"field-minute-narrow": "분",
	"dayPeriods-standAlone-wide-afternoon1": "오후",
	"dateFormatItem-yQQQ": "y년 QQQ",
	"days-format-wide": [
		"일요일",
		"월요일",
		"화요일",
		"수요일",
		"목요일",
		"금요일",
		"토요일"
	],
	"field-mon-narrow-relative+0": "이번 월요일",
	"dateFormatItem-EHm": "(E) HH:mm",
	"field-mon-narrow-relative+1": "다음 월요일",
	"dayPeriods-standAlone-wide-midnight": "자정",
	"dateFormatItem-GyMMMEEEEd": "G y년 MMM d일 EEEE",
	"dateFormatItem-yM": "y. M.",
	"field-zone": "시간대",
	"dateFormatItem-yMMMM": "y년 MMMM",
	"dateFormatItem-MMMEd": "MMM d일 (E)",
	"field-weekOfMonth-narrow": "월의 주",
	"dateFormatItem-EHms": "(E) HH:mm:ss",
	"dateFormatItem-yMEd": "y. M. d. (E)",
	"field-weekday-narrow": "요일",
	"dayPeriods-standAlone-narrow-midnight": "자정",
	"field-quarter-narrow": "분기",
	"dayPeriods-standAlone-abbr-am": "AM",
	"field-day-relative+-1": "어제",
	"field-sun-short-relative+-1": "지난 일요일",
	"field-day-relative+-2": "그저께",
	"dayPeriods-format-narrow-night1": "밤",
	"field-weekday-short": "요일",
	"dateFormatItem-Bhm": "B h:mm",
	"days-format-abbr": [
		"일",
		"월",
		"화",
		"수",
		"목",
		"금",
		"토"
	],
	"field-sun-relative+0": "이번 일요일",
	"field-sun-relative+1": "다음 일요일",
	"dateFormatItem-yMMMd": "y년 MMM d일",
	"dateFormatItem-Gy": "G y년",
	"field-era": "연호",
	"field-week-narrow": "주",
	"field-day-short": "일",
	"dayPeriods-standAlone-abbr-evening1": "저녁",
	"field-fri-narrow-relative+0": "이번 금요일",
	"dayPeriods-format-narrow-evening1": "저녁",
	"field-fri-narrow-relative+1": "다음 금요일",
	"dayPeriods-standAlone-wide-am": "오전",
	"dateFormatItem-yMEEEEd": "y. M. d. EEEE"
}
//end v1.x content
);